@@ -7,7 +7,7 @@ import json
 import urllib.parse as urlparse
 
 from typing import (
-    TYPE_CHECKING, Any, Callable, Dict, List, Mapping, Optional
+    TYPE_CHECKING, Any, Callable, ClassVar, Dict, List, Mapping, Optional,
 )
 
 import param
@@ -58,7 +58,7 @@ class Location(Syncable):
         should be set to False""")
 
     # Mapping from parameter name to bokeh model property name
-    _rename = {"name": None}
+    _rename: ClassVar[Mapping[str, str | None]] = {"name": None}
 
     def __init__(self, **params):
         super().__init__(**params)
@@ -79,7 +79,8 @@ class Location(Syncable):
         return model
 
     def get_root(
-        self, doc: Optional[Document] = None, comm: Optional[Comm] = None, preprocess: bool = True
+        self, doc: Optional[Document] = None, comm: Optional[Comm] = None,
+        preprocess: bool = True
     ) -> 'Model':
         doc = init_doc(doc)
         root = self._get_model(doc, comm=comm)
@@ -88,7 +89,7 @@ class Location(Syncable):
         self._documents[doc] = root
         return root
 
-    def _cleanup(self, root: Optional['Model']) -> None:
+    def _cleanup(self, root: Model | None = None) -> None:
         if root:
             if root.document in self._documents:
                 del self._documents[root.document]
@@ -220,15 +221,20 @@ class Location(Syncable):
             ptype = type(parameterized)
             raise ValueError(f"Cannot unsync {ptype} object since it "
                              "was never synced in the first place.")
-        synced = []
+        synced, unsynced = [], []
         for p, params, watcher, on_error in self._synced:
-            if parameterized is p:
-                parameterized.param.unwatch(watcher)
-                if parameters is not None:
-                    new_params = {p: q for p, q in params.items()
-                                  if p not in parameters}
-                    new_watcher = parameterized.param.watch(watcher.fn, list(new_params))
-                    synced.append((p, new_params, new_watcher, on_error))
-            else:
+            if parameterized is not p:
                 synced.append((p, params, watcher, on_error))
+                continue
+            parameterized.param.unwatch(watcher)
+            if parameters is None:
+                unsynced.extend(list(params.values()))
+            else:
+                unsynced.extend([q for p, q in params.items() if p in parameters])
+                new_params = {p: q for p, q in params.items()
+                              if p not in parameters}
+                new_watcher = parameterized.param.watch(watcher.fn, list(new_params))
+                synced.append((p, new_params, new_watcher, on_error))
         self._synced = synced
+        query = {k: v for k, v in self.query_params.items() if k not in unsynced}
+        self.search = '?' + urlparse.urlencode(query) if query else ''
