@@ -4,10 +4,11 @@ from typing import TYPE_CHECKING, Optional
 
 import param
 
+from ..config import config
 from ..reactive import ReactiveHTML
 from ..util import classproperty
 from .datamodel import _DATA_MODELS, construct_data_model
-from .resources import bundled_files, CSS_URLS
+from .resources import CSS_URLS, bundled_files
 
 if TYPE_CHECKING:
     from bokeh.document import Document
@@ -57,6 +58,8 @@ class NotificationAreaBase(ReactiveHTML):
     </div>
     """
 
+    _extension_name = 'notifications'
+
     __abstract = True
 
     def __init__(self, **params):
@@ -64,7 +67,8 @@ class NotificationAreaBase(ReactiveHTML):
         self._notification_watchers = {}
 
     def get_root(
-        self, doc: Optional['Document'] = None, comm: Optional['Comm'] = None, preprocess: bool = True
+        self, doc: Optional[Document] = None, comm: Optional[Comm] = None,
+        preprocess: bool = True
     ) -> 'Model':
         root = super().get_root(doc, comm, preprocess)
         self._documents[doc] = root
@@ -128,7 +132,7 @@ class NotificationArea(NotificationAreaBase):
         },
     ])
 
-    __javascript_raw__ = ["https://cdn.jsdelivr.net/npm/notyf@3/notyf.min.js"]
+    __javascript_raw__ = [f"{config.npm_cdn}/notyf@3/notyf.min.js"]
 
     @classproperty
     def __javascript__(cls):
@@ -143,7 +147,7 @@ class NotificationArea(NotificationAreaBase):
     }
 
     __css_raw__ = [
-        "https://cdn.jsdelivr.net/npm/notyf@3/notyf.min.css",
+        f"{config.npm_cdn}/notyf@3/notyf.min.css",
         CSS_URLS['font-awesome']
     ]
 
@@ -212,7 +216,9 @@ class NotificationArea(NotificationAreaBase):
         Generates a layout which allows demoing the component.
         """
         from ..layout import Column
-        from ..widgets import Button, ColorPicker, NumberInput, Select, TextInput
+        from ..widgets import (
+            Button, ColorPicker, NumberInput, Select, TextInput,
+        )
 
         msg = TextInput(name='Message', value='This is a message')
         duration = NumberInput(name='Duration', value=0, end=10000)
