@@ -6,6 +6,8 @@ import copy
 import glob
 import importlib
 import json
+import logging
+import mimetypes
 import os
 
 from base64 import b64encode
@@ -29,6 +31,8 @@ from ..config import config
 from ..util import isurl, url_path
 from .state import state
 
+logger = logging.getLogger(__name__)
+
 with open(Path(__file__).parent.parent / 'package.json') as f:
     package_json = json.load(f)
     JS_VERSION = package_json['version'].split('+')[0]
@@ -97,6 +101,15 @@ JS_URLS = {
 
 extension_dirs['panel'] = str(DIST_DIR)
 
+if mimetypes.types_map.get('.js') == 'text/plain':
+    logger.warn(
+        "Mimetype declaration for .js files was set to 'text/plain'. "
+        "This will interefere with serving JS modules. Ensure your system "
+        "does not override the mimetype declaration and/or contact your "
+        "system administrator. "
+    )
+    mimetypes.add_type("application/javascript", ".js")
+
 @contextmanager
 def set_resource_mode(mode):
     global RESOURCE_MODE
@@ -395,6 +408,8 @@ class Bundle(BkBundle):
         for model in param.concrete_descendents(ReactiveHTML).values():
             if getattr(model, '__javascript_modules__', None) and model._loaded():
                 for js_module in model.__javascript_modules__:
+                    if not isurl(js_module) and not js_module.startswith('static/extensions'):
+                        js_module = component_resource_path(model, '__javascript_modules__', js_module)
                     if js_module not in js_modules:
                         js_modules.append(js_module)
         self.js_modules = kwargs.pop("js_modules", js_modules)
