@@ -1,18 +1,24 @@
 """
 Layout component to lay out objects in a set of tabs.
 """
+from __future__ import annotations
+
 from collections import defaultdict
+from typing import (
+    TYPE_CHECKING, ClassVar, List, Mapping, Type,
+)
 
 import param
 
-from bokeh.models import (
-    Spacer as BkSpacer, Panel as BkPanel
-)
+from bokeh.models import Panel as BkPanel, Spacer as BkSpacer
 
 from ..models import Tabs as BkTabs
 from ..viewable import Layoutable
 from .base import NamedListPanel
 
+if TYPE_CHECKING:
+    from bokeh.model import Model
+
 
 class Tabs(NamedListPanel):
     """
@@ -47,21 +53,25 @@ class Tabs(NamedListPanel):
 
     width = param.Integer(default=None, bounds=(0, None))
 
-    _bokeh_model = BkTabs
+    _bokeh_model: ClassVar[Type[Model]] = BkTabs
 
-    _js_transforms = {'tabs': """
+    _js_transforms: ClassVar[Mapping[str, str]] = {'tabs': """
     var ids = [];
     for (var t of value) {{ ids.push(t.id) }};
     var value = ids;
     """}
 
-    _linked_props = ['active', 'tabs']
+    _linked_props: ClassVar[List[str]] = ['active', 'tabs']
 
-    _manual_params = ['closable']
+    _manual_params: ClassVar[List[str]] = ['closable']
 
-    _rename = {'name': None, 'objects': 'tabs', 'dynamic': None}
+    _rename: ClassVar[Mapping[str, str | None]] = {
+        'name': None, 'objects': 'tabs', 'dynamic': None
+    }
 
-    _source_transforms = {'dynamic': None, 'objects': None}
+    _source_transforms: ClassVar[Mapping[str, str | None]] = {
+        'dynamic': None, 'objects': None
+    }
 
     def __init__(self, *objects, **params):
         super().__init__(*objects, **params)
@@ -73,12 +83,13 @@ class Tabs(NamedListPanel):
         self.param.active.bounds = (0, len(event.new)-1)
         super()._update_names(event)
 
-    def _cleanup(self, root):
+    def _cleanup(self, root: Model | None = None) -> None:
         super()._cleanup(root)
-        if root.ref['id'] in self._panels:
-            del self._panels[root.ref['id']]
-        if root.ref['id'] in self._rendered:
-            del self._rendered[root.ref['id']]
+        if root:
+            if root.ref['id'] in self._panels:
+                del self._panels[root.ref['id']]
+            if root.ref['id'] in self._rendered:
+                del self._rendered[root.ref['id']]
 
     @property
     def _preprocess_params(self):
