@@ -1,15 +1,17 @@
 from collections import OrderedDict
 
-from bokeh.core.properties import Any, Dict, Int, String
+from bokeh.core.properties import (
+    Any, Dict, Int, String,
+)
 from bokeh.events import ModelEvent
 from bokeh.models import HTMLBox
 
+from ..config import config
 from ..io.resources import bundled_files
 from ..util import classproperty
 
-
-XTERM_JS = "https://unpkg.com/xterm@4.14.1/lib/xterm.js"
-XTERM_LINKS_JS = "https://unpkg.com/xterm-addon-web-links@0.4.0/lib/xterm-addon-web-links.js"
+XTERM_JS = f"{config.npm_cdn}/xterm@4.14.1/lib/xterm.js"
+XTERM_LINKS_JS = f"{config.npm_cdn}/xterm-addon-web-links@0.4.0/lib/xterm-addon-web-links.js"
 
 
 class KeystrokeEvent(ModelEvent):
@@ -24,7 +26,7 @@ class KeystrokeEvent(ModelEvent):
 class Terminal(HTMLBox):
     """Custom Terminal Model"""
 
-    __css_raw__ = ["https://unpkg.com/xterm@4.11.0/css/xterm.css"]
+    __css_raw__ = [f"{config.npm_cdn}/xterm@4.11.0/css/xterm.css"]
 
     @classproperty
     def __css__(cls):
