@@ -1,4 +1,5 @@
 import {linspace} from "@bokehjs/core/util/array"
+import {Enum} from "@bokehjs/core/kinds"
 
 export const ARRAY_TYPES = {
   uint8:   Uint8Array,
@@ -13,11 +14,12 @@ export const ARRAY_TYPES = {
 
 export type DType = keyof typeof ARRAY_TYPES
 
-export const vtk = (window as any).vtk
-
 export const vtkns: any = {}
 
-if (vtk) {
+export function setup_vtkns(): void {
+  if (vtkns.Actor != null)
+    return
+  const vtk = (window as any).vtk
   vtkns["Actor"] = vtk.Rendering.Core.vtkActor
   vtkns["AxesActor"] = vtk.Rendering.Core.vtkAxesActor
   vtkns["Base64"] = vtk.Common.Core.vtkBase64
@@ -86,8 +88,17 @@ if (vtk) {
     vtkns.Follower.newInstance,
     vtkObjectManager.genericUpdater
   )
+  vtkObjectManager.setTypeMapping(
+    "vtkOpenGLGlyph3DMapper",
+    vtkns.Glyph3DMapper.newInstance,
+    vtkObjectManager.genericUpdater
+  )
 }
 
+
+if ((window as any).vtk)
+  setup_vtkns()
+
 declare type RGBnode = {
   x: number
   r: number
@@ -95,11 +106,32 @@ declare type RGBnode = {
   b: number
 }
 
-export declare type ColorMapper = {
+export type ColorMapper = {
   palette: string[]
   low: number
   high: number
 }
+
+
+export const Interpolation = Enum("fast_linear", "linear", "nearest")
+export type Interpolation = typeof Interpolation["__type__"]
+
+export type Annotation = {
+  id: string
+  viewport: number[]
+  fontSize: number
+  fontFamily: string
+  color: number[]
+  LowerLeft?: string
+  LowerRight?: string
+  UpperLeft?: string
+  UpperRight?: string
+  LowerEdge?: string
+  RightEdge?: string
+  LeftEdge?: string
+  UpperEdge?: string
+}
+
 export declare type CSSProperties = {[key: string]: string}
 
 export declare type VolumeType = {
