@@ -2,25 +2,37 @@
 HoloViews integration for Panel including a Pane to render HoloViews
 objects and their widgets and support for Links
 """
+from __future__ import annotations
+
 import sys
 
 from collections import OrderedDict, defaultdict
-from packaging.version import Version
 from functools import partial
+from typing import (
+    TYPE_CHECKING, Any, ClassVar, Mapping, Optional, Type,
+)
 
 import param
 
-from bokeh.models import Spacer as _BkSpacer, Range1d
+from bokeh.models import Range1d, Spacer as _BkSpacer
 from bokeh.themes.theme import Theme
+from packaging.version import Version
 
 from ..io import state, unlocked
-from ..layout import Column, WidgetBox, HSpacer, VSpacer, Row
+from ..layout import (
+    Column, HSpacer, Row, VSpacer, WidgetBox,
+)
 from ..viewable import Layoutable, Viewable
 from ..widgets import Player
-from .base import PaneBase, Pane, RerenderError
+from .base import Pane, PaneBase, RerenderError
 from .plot import Bokeh, Matplotlib
 from .plotly import Plotly
 
+if TYPE_CHECKING:
+    from bokeh.document import Document
+    from bokeh.model import Model
+    from pyviz_comms import Comm
+
 
 class HoloViews(PaneBase):
     """
@@ -77,11 +89,13 @@ class HoloViews(PaneBase):
         A mapping from dimension name to a widget instance which will
         be used to override the default widgets.""")
 
-    priority = 0.8
+    priority: ClassVar[float | bool | None] = 0.8
 
-    _panes = {'bokeh': Bokeh, 'matplotlib': Matplotlib, 'plotly': Plotly}
+    _panes: ClassVar[Mapping[str, Type[PaneBase]]] = {
+        'bokeh': Bokeh, 'matplotlib': Matplotlib, 'plotly': Plotly
+    }
 
-    _rename = {
+    _rename: ClassVar[Mapping[str, str | None]] = {
         'backend': None, 'center': None, 'linked_axes': None,
         'renderer': None, 'theme': None, 'widgets': None,
         'widget_layout': None, 'widget_location': None,
@@ -91,16 +105,27 @@ class HoloViews(PaneBase):
     _rerender_params = ['object', 'backend']
 
     def __init__(self, object=None, **params):
-        super().__init__(object, **params)
         self._initialized = False
         self._responsive_content = False
         self._restore_plot = None
+        super().__init__(object, **params)
         self.widget_box = self.widget_layout()
         self._widget_container = []
-        self._update_widgets()
         self._plots = {}
-        self.param.watch(self._update_widgets, self._rerender_params)
+        self._syncing_props = False
+        self._overrides = [
+            p for p, v in params.items()
+            if p in Layoutable.param and v != self.param[p].default
+        ]
+        watcher = self.param.watch(self._update_widgets, self._rerender_params)
+        self._callbacks.append(watcher)
         self._initialized = True
+        self._update_responsive()
+        self._update_widgets()
+
+    def _param_change(self, *events: param.parameterized.Event) -> None:
+        self._track_overrides(*(e for e in events if e.name in Layoutable.param))
+        super()._param_change(*(e for e in events if e.name in self._overrides))
 
     @param.depends('center', 'widget_location', watch=True)
     def _update_layout(self):
@@ -160,6 +185,50 @@ class HoloViews(PaneBase):
             if model.document:
                 model.document.theme = self.theme
 
+    @param.depends('object', watch=True)
+    def _update_responsive(self):
+        from holoviews import HoloMap, Store
+        from holoviews.plotting import Plot
+        obj = self.object
+        if isinstance(obj, Plot):
+            if 'responsive' in obj.param:
+                responsive = obj.responsive
+            elif 'sizing_mode' in obj.param:
+                mode = obj.sizing_mode
+                if mode:
+                    responsive = '_width' in mode or '_both' in mode
+                else:
+                    responsive = False
+            else:
+                responsive = False
+            self._responsive_content = responsive
+            return
+
+        obj = obj.last if isinstance(obj, HoloMap) else obj
+        if obj is None or not Store.renderers:
+            return
+        backend = self.backend or Store.current_backend
+        renderer = self.renderer or Store.renderers[backend]
+        opts = obj.opts.get('plot', backend=backend).kwargs
+        plot_cls = renderer.plotting_class(obj)
+        if backend == 'matplotlib':
+            self._responsive_content = False
+        elif backend == 'plotly':
+            responsive = opts.get('responsive', None)
+            width = opts.get('width', None)
+            self._responsive_content = responsive and not width
+        elif 'sizing_mode' in plot_cls.param:
+            mode = opts.get('sizing_mode')
+            if mode:
+                self._responsive_content = '_width' in mode or '_both' in mode
+            else:
+                self._responsive_content = False
+        else:
+            responsive = opts.get('responsive', None)
+            width = opts.get('width', None)
+            frame_width = opts.get('frame_width', None)
+            self._responsive_content = responsive and not width and not frame_width
+
     @param.depends('widget_type', 'widgets', watch=True)
     def _update_widgets(self, *events):
         if self.object is None:
@@ -225,11 +294,61 @@ class HoloViews(PaneBase):
         for _, (plot, pane) in self._plots.items():
             self._update_plot(plot, pane)
 
+    def _track_overrides(self, *events):
+        if self._syncing_props:
+            return
+        overrides = list(self._overrides)
+        for e in events:
+            if e.name in overrides and self.param[e.name].default == e.new:
+                overrides.remove(e.name)
+            else:
+                overrides.append(e.name)
+        self._overrides = overrides
+
+    def _sync_sizing_mode(self, plot):
+        state = plot.state
+        backend = plot.renderer.backend
+        if backend == 'bokeh':
+            params = {
+                'sizing_mode': state.sizing_mode,
+                'width': state.width,
+                'height': state.height
+            }
+        elif backend == 'matplotlib':
+            params = {
+                'sizing_mode': None,
+                'width': None,
+                'height': None
+            }
+        elif backend == 'plotly':
+            if state.get('config', {}).get('responsive'):
+                sizing_mode = 'stretch_both'
+            else:
+                sizing_mode = None
+            params = {
+                'sizing_mode': sizing_mode,
+                'width': None,
+                'height': None
+            }
+        self._syncing_props = True
+        try:
+            self.param.update({k: v for k, v in params.items() if k not in self._overrides})
+            props = {
+                o: getattr(self, o) for o in self._overrides
+            }
+            if props:
+                plot.state.update(**props)
+        finally:
+            self._syncing_props = False
+
     #----------------------------------------------------------------
     # Model API
     #----------------------------------------------------------------
 
-    def _get_model(self, doc, root=None, parent=None, comm=None):
+    def _get_model(
+        self, doc: Document, root: Optional[Model] = None,
+        parent: Optional[Model] = None, comm: Optional[Comm] = None
+    ) -> Model:
         from holoviews.plotting.plot import Plot
         if root is None:
             return self.get_root(doc, comm)
@@ -256,15 +375,13 @@ class HoloViews(PaneBase):
             state = plot.state
 
         # Ensure rerender if content is responsive but layout is centered
-        if (backend == 'bokeh' and self.center and
-            state.sizing_mode not in ('fixed', None)
-            and not self._responsive_content):
+        self._sync_sizing_mode(plot)
+        responsive = self.sizing_mode not in ('fixed', None) and not self.width
+        if self.center and responsive and not self._responsive_content:
             self._responsive_content = True
             self._update_layout()
             self._restore_plot = plot
             raise RerenderError()
-        else:
-            self._responsive_content = False
 
         kwargs = {p: v for p, v in self.param.values().items()
                   if p in Layoutable.param and p != 'name'}
@@ -290,6 +407,7 @@ class HoloViews(PaneBase):
 
     def _render(self, doc, comm, root):
         import holoviews as hv
+
         from holoviews import Store, renderer as load_renderer
 
         if self.renderer:
@@ -323,16 +441,17 @@ class HoloViews(PaneBase):
 
         return renderer.get_plot(self.object, **kwargs)
 
-    def _cleanup(self, root):
+    def _cleanup(self, root: Model | None = None) -> None:
         """
         Traverses HoloViews object to find and clean up any streams
         connected to existing plots.
         """
-        old_plot, old_pane = self._plots.pop(root.ref['id'], (None, None))
-        if old_plot:
-            old_plot.cleanup()
-        if old_pane:
-            old_pane._cleanup(root)
+        if root:
+            old_plot, old_pane = self._plots.pop(root.ref['id'], (None, None))
+            if old_plot:
+                old_plot.cleanup()
+            if old_pane:
+                old_pane._cleanup(root)
         super()._cleanup(root)
 
     #----------------------------------------------------------------
@@ -340,7 +459,7 @@ class HoloViews(PaneBase):
     #----------------------------------------------------------------
 
     @classmethod
-    def applies(cls, obj):
+    def applies(cls, obj: Any) -> float | bool | None:
         if 'holoviews' not in sys.modules:
             return False
         from holoviews.core.dimension import Dimensioned
@@ -368,11 +487,17 @@ class HoloViews(PaneBase):
     def widgets_from_dimensions(cls, object, widget_types=None, widgets_type='individual'):
         from holoviews.core import Dimension, DynamicMap
         from holoviews.core.options import SkipRendering
-        from holoviews.core.util import isnumeric, datetime_types, unique_iterator
         from holoviews.core.traversal import unique_dimkeys
-        from holoviews.plotting.plot import Plot, GenericCompositePlot
+        from holoviews.core.util import (
+            datetime_types, isnumeric, unique_iterator,
+        )
+        from holoviews.plotting.plot import GenericCompositePlot, Plot
         from holoviews.plotting.util import get_dynamic_mode
-        from ..widgets import Widget, DiscreteSlider, Select, FloatSlider, DatetimeInput, IntSlider
+
+        from ..widgets import (
+            DatetimeInput, DiscreteSlider, FloatSlider, IntSlider, Select,
+            Widget,
+        )
 
         if widget_types is None:
             widget_types = {}
@@ -487,7 +612,7 @@ class HoloViews(PaneBase):
 
 class Interactive(PaneBase):
 
-    priority = None
+    priority: ClassVar[float | bool | None] = None
 
     def __init__(self, object=None, **params):
         super().__init__(object, **params)
@@ -495,7 +620,7 @@ class Interactive(PaneBase):
         self.param.watch(self._update_layout_properties, list(Layoutable.param))
 
     @classmethod
-    def applies(cls, object):
+    def applies(cls, object: Any) -> float | bool | None:
         if 'hvplot.interactive' not in sys.modules:
             return False
         from hvplot.interactive import Interactive
@@ -516,7 +641,10 @@ class Interactive(PaneBase):
             return
         self._layout_panel.param.update(**{e.name: e.new for e in events})
 
-    def _get_model(self, doc, root=None, parent=None, comm=None):
+    def _get_model(
+        self, doc: Document, root: Optional[Model] = None,
+        parent: Optional[Model] = None, comm: Optional[Comm] = None
+    ) -> Model:
         if root is None:
             return self.get_root(doc, comm)
         if self._layout_panel is None:
@@ -528,7 +656,7 @@ class Interactive(PaneBase):
         self._models[root.ref['id']] = (model, parent)
         return model
 
-    def _cleanup(self, root):
+    def _cleanup(self, root: Model | None = None) -> None:
         if self._layout_panel is not None:
             self._layout_panel._cleanup(root)
         super()._cleanup(root)
@@ -539,7 +667,9 @@ def is_bokeh_element_plot(plot):
     Checks whether plotting instance is a HoloViews ElementPlot rendered
     with the bokeh backend.
     """
-    from holoviews.plotting.plot import GenericElementPlot, GenericOverlayPlot, Plot
+    from holoviews.plotting.plot import (
+        GenericElementPlot, GenericOverlayPlot, Plot,
+    )
     if not isinstance(plot, Plot):
         return False
     return (plot.renderer.backend == 'bokeh' and isinstance(plot, GenericElementPlot)
@@ -577,8 +707,11 @@ def find_links(root_view, root_model):
         return
 
     try:
+        try:
+            from holoviews.plotting.bokeh.links import LinkCallback
+        except Exception:
+            from holoviews.plotting.bokeh.callbacks import LinkCallback
         from holoviews.plotting.links import Link
-        from holoviews.plotting.bokeh.callbacks import LinkCallback
     except Exception:
         return
 
@@ -587,6 +720,7 @@ def find_links(root_view, root_model):
 
     potentials = [(LinkCallback.find_link(plot), root_plot)
                   for plot, root_plot in plots]
+
     source_links = [p for p in potentials if p[0] is not None]
     found = []
     for (plot, links), root_plot in source_links:
@@ -624,7 +758,7 @@ def link_axes(root_view, root_model):
         return
 
     from holoviews.core.options import Store
-    from holoviews.core.util import unique_iterator, max_range
+    from holoviews.core.util import max_range, unique_iterator
     from holoviews.plotting.bokeh.element import ElementPlot
 
     ref = root_model.ref['id']
@@ -667,13 +801,13 @@ def link_axes(root_view, root_model):
             changed = []
             if  type(ax) is not type(pax):
                 continue
-            if tag in fig.x_range.tags and not axis is fig.x_range:
+            if tag in fig.x_range.tags and axis is not fig.x_range:
                 if hasattr(axis, 'factors'):
                     axis.factors = list(unique_iterator(axis.factors+fig.x_range.factors))
                 fig.x_range = axis
                 p.handles['x_range'] = axis
                 changed.append('x_range')
-            if tag in fig.y_range.tags and not axis is fig.y_range:
+            if tag in fig.y_range.tags and axis is not fig.y_range:
                 if hasattr(axis, 'factors'):
                     axis.factors = list(unique_iterator(axis.factors+fig.y_range.factors))
                 fig.y_range = axis
