@@ -2,16 +2,21 @@
 Contains Image panes including renderers for PNG, SVG, GIF and JPG
 file types.
 """
+from __future__ import annotations
+
+import asyncio
 import base64
 
-from pathlib import PurePath
-
 from io import BytesIO
+from pathlib import PurePath
+from typing import (
+    Any, ClassVar, List, Mapping,
+)
 
 import param
 
-from .markup import escape, DivPaneBase
 from ..util import isfile, isurl
+from .markup import DivPaneBase, escape
 
 
 class FileBase(DivPaneBase):
@@ -19,7 +24,9 @@ class FileBase(DivPaneBase):
     embed = param.Boolean(default=True, doc="""
         Whether to embed the file as base64.""")
 
-    _rerender_params = ['embed', 'object', 'style', 'width', 'height']
+    _rerender_params: ClassVar[List[str]] = [
+        'embed', 'object', 'style', 'width', 'height'
+    ]
 
     __abstract = True
 
@@ -35,7 +42,7 @@ class FileBase(DivPaneBase):
         super()._type_error(object)
 
     @classmethod
-    def applies(cls, obj):
+    def applies(cls, obj: Any) -> float | bool | None:
         filetype = cls.filetype
         if hasattr(obj, '_repr_{}_'.format(filetype)):
             return True
@@ -72,9 +79,20 @@ class FileBase(DivPaneBase):
                 self.object.seek(0)
             return self.object.read()
         if isurl(self.object, None):
-            import requests
-            r = requests.request(url=self.object, method='GET')
-            return r.content
+            from ..io.state import state
+            if state._is_pyodide:
+                from ..io.pyodide import _IN_WORKER, fetch_binary
+                if _IN_WORKER:
+                    return fetch_binary(self.object).read()
+                else:
+                    from pyodide.http import pyfetch
+                    async def replace_content():
+                        self.object = await (await pyfetch(self.object)).bytes()
+                    asyncio.create_task(replace_content())
+            else:
+                import requests
+                r = requests.request(url=self.object, method='GET')
+                return r.content
 
 
 class ImageBase(FileBase):
@@ -99,11 +117,15 @@ class ImageBase(FileBase):
         A link URL to make the image clickable and link to some other
         website.""")
 
-    filetype = 'None'
+    filetype: ClassVar[str] = 'None'
 
-    _rerender_params = ['alt_text', 'link_url', 'embed', 'object', 'style', 'width', 'height']
+    _rerender_params: ClassVar[List[str]] = [
+        'alt_text', 'link_url', 'embed', 'object', 'style', 'width', 'height'
+    ]
 
-    _target_transforms = {'object': """'<img src="' + value + '"></img>'"""}
+    _target_transforms: ClassVar[Mapping[str, str | None]] = {
+        'object': """'<img src="' + value + '"></img>'"""
+    }
 
     __abstract = True
 
@@ -123,6 +145,8 @@ class ImageBase(FileBase):
         if self.object is None:
             return dict(p, text='<img></img>')
         data = self._data()
+        if data is None:
+            return dict(p, text='<img></img>')
         if not isinstance(data, bytes):
             data = base64.b64decode(data)
         width, height = self._imgshape(data)
@@ -182,7 +206,7 @@ class PNG(ImageBase):
     ... )
     """
 
-    filetype = 'png'
+    filetype: ClassVar[str] = 'png'
 
     @classmethod
     def _imgshape(cls, data):
@@ -208,7 +232,7 @@ class GIF(ImageBase):
     ... )
     """
 
-    filetype = 'gif'
+    filetype: ClassVar[str] = 'gif'
 
     @classmethod
     def _imgshape(cls, data):
@@ -234,7 +258,7 @@ class ICO(ImageBase):
     ...
     """
 
-    filetype = 'ico'
+    filetype: ClassVar[str] = 'ico'
 
     @classmethod
     def _imgshape(cls, data):
@@ -260,7 +284,7 @@ class JPG(ImageBase):
     ... )
     """
 
-    filetype = 'jpg'
+    filetype: ClassVar[str] = 'jpg'
 
     @classmethod
     def _imgshape(cls, data):
@@ -302,12 +326,12 @@ class SVG(ImageBase):
         Whether to enable base64 encoding of the SVG, base64 encoded
         SVGs do not support links.""")
 
-    filetype = 'svg'
+    filetype: ClassVar[str] = 'svg'
 
-    _rerender_params = ImageBase._rerender_params + ['encode']
+    _rerender_params: ClassVar[List[str]] = ImageBase._rerender_params + ['encode']
 
     @classmethod
-    def applies(cls, obj):
+    def applies(cls, obj: Any) -> float | bool | None:
         return (super().applies(obj) or
                 (isinstance(obj, str) and obj.lstrip().startswith('<svg')))
 
@@ -368,7 +392,7 @@ class PDF(FileBase):
     ... )
     """
 
-    filetype = 'pdf'
+    filetype: ClassVar[str] = 'pdf'
 
     def _get_properties(self):
         p = super()._get_properties()
