@@ -1,25 +1,37 @@
 """
 Defines a VTKPane which renders a vtk plot using VTKPlot bokeh model.
 """
-import sys
-import json
+from __future__ import annotations
+
 import base64
+import json
+import sys
 import zipfile
 
 from abc import abstractmethod
+from typing import (
+    TYPE_CHECKING, Any, ClassVar, Dict, Mapping, Optional,
+)
 from urllib.request import urlopen
 
-import param
 import numpy as np
+import param
 
-from bokeh.util.serialization import make_globally_unique_id
 from bokeh.models import LinearColorMapper
+from bokeh.util.serialization import make_globally_unique_id
 from pyviz_comms import JupyterComm
 
+from ...param import ParamMethod
 from ...util import isfile, lazy_load
-from ..base import PaneBase, Pane
+from ..base import PaneBase
+from ..plot import Bokeh
 from .enums import PRESET_CMAPS
 
+if TYPE_CHECKING:
+    from bokeh.document import Document
+    from bokeh.model import Model
+    from pyviz_comms import Comm
+
 base64encode = lambda x: base64.b64encode(x).decode('utf-8')
 
 
@@ -69,7 +81,10 @@ class AbstractVTK(PaneBase):
             msg['axes'] = VTKAxes(**axes)
         return msg
 
-    def _update_model(self, events, msg, root, model, doc, comm):
+    def _update_model(
+        self, events: Dict[str, param.parameterized.Event], msg: Dict[str, Any],
+        root: Model, model: Model, doc: Document, comm: Optional[Comm]
+    ) -> None:
         if 'axes' in msg and msg['axes'] is not None:
             VTKAxes = getattr(sys.modules['panel.models.vtk'], 'VTKAxes')
             axes = msg['axes']
@@ -224,7 +239,7 @@ class BaseVTKRenderWindow(AbstractVTK):
 
     _applies_kw = True
 
-    _rename = {'serialize_on_instantiation': None, 'serialize_all_data_arrays': None}
+    _rename: ClassVar[Mapping[str, str | None]] = {'serialize_on_instantiation': None, 'serialize_all_data_arrays': None}
 
     __abstract = True
 
@@ -278,7 +293,7 @@ class BaseVTKRenderWindow(AbstractVTK):
     def _construct_colorbars(self, color_mappers=None):
         if not color_mappers:
             color_mappers = self.color_mappers
-        from bokeh.models import Plot, ColorBar, FixedTicker
+        from bokeh.models import ColorBar, FixedTicker, Plot
         cbs = []
         for color_mapper in color_mappers:
             ticks = np.linspace(color_mapper.low, color_mapper.high, 5)
@@ -295,10 +310,11 @@ class BaseVTKRenderWindow(AbstractVTK):
 
     def construct_colorbars(self, infer=True):
         if infer:
-            color_mappers = self.get_color_mappers(infer)
-            return Pane(self._construct_colorbars(color_mappers))
+            color_mappers = self.get_color_mappers(infer=True)
+            model = self._construct_colorbars(color_mappers)
+            return Bokeh(model)
         else:
-            return Pane(self._construct_colorbars)
+            return ParamMethod(self._construct_colorbars)
 
     def export_scene(self, filename='vtk_scene', all_data_arrays=False):
         if '.' not in filename:
@@ -364,9 +380,12 @@ class VTKRenderWindow(BaseVTKRenderWindow):
         super(VTKRenderWindow, self).__init__(object, **params)
         if object is not None:
             self.color_mappers = self.get_color_mappers()
-            self._update()
+            self._update(None, None)
 
-    def _get_model(self, doc, root=None, parent=None, comm=None):
+    def _get_model(
+        self, doc: Document, root: Optional[Model] = None,
+        parent: Optional[Model] = None, comm: Optional[Comm] = None
+    ) -> Model:
         VTKSynchronizedPlot = lazy_load(
             'panel.models.vtk', 'VTKSynchronizedPlot', isinstance(comm, JupyterComm), root
         )
@@ -383,7 +402,7 @@ class VTKRenderWindow(BaseVTKRenderWindow):
         self._models[root.ref['id']] = (model, parent)
         return model
 
-    def _update(self, ref=None, model=None):
+    def _update(self, ref: str, model: Model) -> None:
         import panel.pane.vtk.synchronizable_serializer as rws
         context = rws.SynchronizationContext(
             id_root=make_globally_unique_id(),
@@ -410,7 +429,7 @@ class VTKRenderWindowSynchronized(BaseVTKRenderWindow, SyncHelpers):
 
     _one_time_reset = param.Boolean(default=False)
 
-    _rename = dict(_one_time_reset='one_time_reset',
+    _rename: ClassVar[Mapping[str, str | None]] = dict(_one_time_reset='one_time_reset',
                    **BaseVTKRenderWindow._rename)
 
     _updates = True
@@ -426,7 +445,10 @@ class VTKRenderWindowSynchronized(BaseVTKRenderWindow, SyncHelpers):
         super().__init__(object, **params)
         self._contexts = {}
 
-    def _get_model(self, doc, root=None, parent=None, comm=None):
+    def _get_model(
+        self, doc: Document, root: Optional[Model] = None,
+        parent: Optional[Model] = None, comm: Optional[Comm] = None
+    ) -> Model:
         VTKSynchronizedPlot = lazy_load(
             'panel.models.vtk', 'VTKSynchronizedPlot', isinstance(comm, JupyterComm), root
         )
@@ -452,12 +474,12 @@ class VTKRenderWindowSynchronized(BaseVTKRenderWindow, SyncHelpers):
         self._models[root.ref['id']] = (model, parent)
         return model
 
-    def _cleanup(self, root):
+    def _cleanup(self, root: Model | None = None) -> None:
         ref = root.ref['id']
         self._contexts.pop(ref, None)
         super()._cleanup(root)
 
-    def _update(self, ref=None, model=None):
+    def _update(self, ref: str, model: Model) -> None:
         context = self._contexts[model.id]
         scene, arrays, annotations = self._serialize_ren_win(
             self.object,
@@ -624,17 +646,17 @@ class VTKVolume(AbstractVTK):
 
     _serializers = {}
 
-    _rename = {'max_data_size': None, 'spacing': None, 'origin': None}
+    _rename: ClassVar[Mapping[str, str | None]] = {'max_data_size': None, 'spacing': None, 'origin': None}
 
     _updates = True
 
     def __init__(self, object=None, **params):
         super().__init__(object, **params)
         self._sub_spacing = self.spacing
-        self._update()
+        self._update(None, None)
 
     @classmethod
-    def applies(cls, obj):
+    def applies(cls, obj: Any) -> float | bool | None:
         if ((isinstance(obj, np.ndarray) and obj.ndim == 3) or
             any([isinstance(obj, k) for k in cls._serializers.keys()])):
             return True
@@ -644,7 +666,10 @@ class VTKVolume(AbstractVTK):
             import vtk
             return isinstance(obj, vtk.vtkImageData)
 
-    def _get_model(self, doc, root=None, parent=None, comm=None):
+    def _get_model(
+        self, doc: Document, root: Optional[Model] = None,
+        parent: Optional[Model] = None, comm: Optional[Comm] = None
+    ) -> Model:
         VTKVolumePlot = lazy_load(
             'panel.models.vtk', 'VTKVolumePlot', isinstance(comm, JupyterComm), root
         )
@@ -693,7 +718,7 @@ class VTKVolume(AbstractVTK):
                     msg[k] = int(np.round(v * ori_dim[index] / sub_dim[index]))
         return msg
 
-    def _update(self, ref=None, model=None):
+    def _update(self, ref: str, model: Model) -> None:
         self._volume_data = self._get_volume_data()
         if self._volume_data is not None:
             self._orginal_dimensions = self._get_object_dimensions()
@@ -733,6 +758,7 @@ class VTKVolume(AbstractVTK):
             available_serializer = [v for k, v in VTKVolume._serializers.items() if isinstance(self.object, k)]
             if not available_serializer:
                 import vtk
+
                 from vtk.util import numpy_support
 
                 def volume_serializer(inst):
@@ -805,11 +831,14 @@ class VTKJS(AbstractVTK):
         self._vtkjs = None
 
     @classmethod
-    def applies(cls, obj):
+    def applies(cls, obj: Any) -> float | bool | None:
         if isinstance(obj, str) and obj.endswith('.vtkjs'):
             return True
 
-    def _get_model(self, doc, root=None, parent=None, comm=None):
+    def _get_model(
+        self, doc: Document, root: Optional[Model] = None,
+        parent: Optional[Model] = None, comm: Optional[Comm] = None
+    ) -> Model:
         """
         Should return the bokeh model to be rendered.
         """
@@ -839,7 +868,7 @@ class VTKJS(AbstractVTK):
             self._vtkjs = vtkjs
         return self._vtkjs
 
-    def _update(self, ref=None, model=None):
+    def _update(self, ref: str, model: Model) -> None:
         self._vtkjs = None
         vtkjs = self._get_vtkjs()
         model.data = base64encode(vtkjs) if vtkjs is not None else vtkjs
