@@ -39,6 +39,12 @@ def port_open(port):
     sock.close()
     return is_open
 
+def get_default_port():
+    # to get a different starting port per worker for pytest-xdist
+    worker_id = os.environ.get("PYTEST_XDIST_WORKER", "0")
+    n = int(re.sub(r"\D", "", worker_id))
+    return 6000 + n * 30
+
 def start_jupyter():
     global JUPYTER_PORT, JUPYTER_PROCESS
     args = ['jupyter', 'server', '--port', str(JUPYTER_PORT), "--NotebookApp.token=''"]
@@ -135,7 +141,7 @@ def context(context):
     context.set_default_timeout(20_000)
     yield context
 
-PORT = [6000]
+PORT = [get_default_port()]
 
 @pytest.fixture
 def document():
@@ -211,14 +217,15 @@ def tmpdir(request, tmpdir_factory):
 
 @pytest.fixture()
 def html_server_session():
+    port = 5050
     html = HTML('<h1>Title</h1>')
-    server = serve(html, port=6000, show=False, start=False)
+    server = serve(html, port=port, show=False, start=False)
     session = pull_session(
         session_id='Test',
         url="http://localhost:{:d}/".format(server.port),
         io_loop=server.io_loop
     )
-    yield html, server, session
+    yield html, server, session, port
     try:
         server.stop()
     except AssertionError:
@@ -227,14 +234,15 @@ def html_server_session():
 
 @pytest.fixture()
 def markdown_server_session():
+    port = 5051
     html = Markdown('#Title')
-    server = serve(html, port=6001, show=False, start=False)
+    server = serve(html, port=port, show=False, start=False)
     session = pull_session(
         session_id='Test',
         url="http://localhost:{:d}/".format(server.port),
         io_loop=server.io_loop
     )
-    yield html, server, session
+    yield html, server, session, port
     try:
         server.stop()
     except AssertionError:
@@ -242,7 +250,7 @@ def markdown_server_session():
 
 
 @pytest.fixture
-def multiple_apps_server_sessions():
+def multiple_apps_server_sessions(port):
     """Serve multiple apps and yield a factory to allow
     parameterizing the slugs and the titles."""
     servers = []
@@ -252,7 +260,7 @@ def multiple_apps_server_sessions():
             app1_slug: Markdown('First app'),
             app2_slug: Markdown('Second app')
         }
-        server = serve(apps, port=5008, title=titles, show=False, start=False)
+        server = serve(apps, port=port, title=titles, show=False, start=False)
         servers.append(server)
         session1 = pull_session(
             url=f"http://localhost:{server.port:d}/app1",
@@ -336,6 +344,13 @@ def py_file():
     finally:
         tf.close()
 
+@pytest.fixture
+def html_file():
+    tf = tempfile.NamedTemporaryFile(mode='w', suffix='.html')
+    try:
+        yield tf
+    finally:
+        tf.close()
 
 @pytest.fixture
 def threads():
