@@ -18,6 +18,11 @@ def test_echart():
     echart = ECHART
     pane = pn.pane.ECharts(echart, width=500, height=500)
     assert pane.object == echart
+
+def manualtest_echart():
+    echart = ECHART
+    pane = pn.pane.ECharts(echart, width=500, height=500)
+    assert pane.object == echart
     return pane
 
 def get_pyechart():
@@ -52,9 +57,9 @@ def get_pyechart2():
         return pn.pane.ECharts(my_plot, width=500, height=250)
     return pn.Row(pn.Column(bar1, bar2), plot)
 
-if __name__.startswith("bokeh"):
-    # test_echart().servable()
+if pn.state.served:
+    # manualtest_echart().servable()
     get_pyechart2().servable()
 if __name__.startswith("__main__"):
-    test_echart().show(port=5007)
+    manualtest_echart().show(port=5007)
     get_pyechart().show(port=5007)
