@@ -1,24 +1,37 @@
 import datetime as dt
+
 from collections import OrderedDict
 
-import pytest
 import numpy as np
+import pytest
 
 try:
     import holoviews as hv
 except Exception:
     hv = None
 
-from bokeh.models import (Row as BkRow, Column as BkColumn, GlyphRenderer,
-                          Scatter, Line, GridBox, Select as BkSelect,
-                          Slider as BkSlider, Spacer as BkSpacer,
-                          ColumnDataSource)
+try:
+    import holoviews.plotting.plotly as hv_plotly
+except Exception:
+    hv_plotly = None
+plotly_available = pytest.mark.skipif(hv_plotly is None, reason="requires plotly backend")
+
+from bokeh.models import (
+    Column as BkColumn, ColumnDataSource, GlyphRenderer, GridBox, Line,
+    Row as BkRow, Scatter, Select as BkSelect, Slider as BkSlider,
+    Spacer as BkSpacer,
+)
 from bokeh.plotting import Figure
 
+import panel as pn
+
+from panel.depends import bind
 from panel.layout import Column, FlexBox, Row
-from panel.pane import Pane, PaneBase, HoloViews
-from panel.widgets import FloatSlider, DiscreteSlider, Select
+from panel.pane import HoloViews, PaneBase, panel
 from panel.tests.util import hv_available, mpl_available
+from panel.widgets import (
+    Checkbox, DiscreteSlider, FloatSlider, Select,
+)
 
 
 @hv_available
@@ -32,7 +45,7 @@ def test_get_holoviews_pane_type():
 @hv_available
 def test_holoviews_pane_mpl_renderer(document, comm):
     curve = hv.Curve([1, 2, 3])
-    pane = Pane(curve)
+    pane = pn.panel(curve)
 
     # Create pane
     row = pane.get_root(document, comm=comm)
@@ -59,7 +72,7 @@ def test_holoviews_pane_mpl_renderer(document, comm):
 @hv_available
 def test_holoviews_pane_switch_backend(document, comm):
     curve = hv.Curve([1, 2, 3])
-    pane = Pane(curve)
+    pane = pn.panel(curve)
 
     # Create pane
     row = pane.get_root(document, comm=comm)
@@ -83,7 +96,7 @@ def test_holoviews_pane_switch_backend(document, comm):
 @hv_available
 def test_holoviews_pane_bokeh_renderer(document, comm):
     curve = hv.Curve([1, 2, 3])
-    pane = Pane(curve)
+    pane = pn.panel(curve)
 
     # Create pane
     row = pane.get_root(document, comm=comm)
@@ -110,7 +123,6 @@ def test_holoviews_pane_bokeh_renderer(document, comm):
     pane._cleanup(row)
     assert pane._models == {}
 
-
 @pytest.mark.usefixtures("hv_bokeh")
 @hv_available
 def test_holoviews_pane_initialize_empty(document, comm):
@@ -128,6 +140,86 @@ def test_holoviews_pane_initialize_empty(document, comm):
     model = row.children[0]
     assert isinstance(model, Figure)
 
+@pytest.mark.usefixtures("hv_bokeh")
+@hv_available
+def test_holoviews_pane_reflect_responsive(document, comm):
+    curve = hv.Curve([1, 2, 3]).opts(responsive=True)
+    pane = HoloViews(curve)
+
+    # Create pane
+    row = pane.get_root(document, comm=comm)
+
+    assert row.sizing_mode == 'stretch_both'
+    assert pane.sizing_mode == 'stretch_both'
+
+    pane.object = hv.Curve([1, 2, 3])
+
+    assert row.sizing_mode == 'fixed'
+    assert pane.sizing_mode == 'fixed'
+
+@pytest.mark.usefixtures("hv_bokeh")
+@hv_available
+def test_holoviews_pane_reflect_responsive_override(document, comm):
+    curve = hv.Curve([1, 2, 3]).opts(responsive=True)
+    pane = HoloViews(curve, sizing_mode='fixed')
+
+    # Create pane
+    row = pane.get_root(document, comm=comm)
+
+    assert row.sizing_mode == 'fixed'
+    assert pane.sizing_mode == 'fixed'
+
+    # Unset override
+    pane.sizing_mode = None
+
+    row = pane.get_root(document, comm=comm)
+
+    assert row.sizing_mode == 'stretch_both'
+    assert pane.sizing_mode == 'stretch_both'
+
+@pytest.mark.usefixtures("hv_bokeh")
+@hv_available
+def test_holoviews_pane_reflect_responsive_interact_function(document, comm):
+    curve_fn = lambda: hv.Curve([1, 2, 3]).opts(responsive=True)
+    pane = panel(curve_fn)
+
+    # Create pane
+    row = pane.get_root(document, comm=comm)
+
+    assert row.sizing_mode == 'stretch_both'
+
+@pytest.mark.usefixtures("hv_bokeh")
+@hv_available
+def test_holoviews_pane_reflect_responsive_bind_function(document, comm):
+    checkbox = Checkbox(value=True)
+    curve_fn = lambda responsive: hv.Curve([1, 2, 3]).opts(responsive=responsive)
+    pane = panel(bind(curve_fn, responsive=checkbox))
+
+    # Create pane
+    col = pane.get_root(document, comm=comm)
+
+    assert col.sizing_mode == 'stretch_both'
+
+    checkbox.value = False
+
+    assert col.sizing_mode == 'fixed'
+
+@hv_available
+@plotly_available
+def test_holoviews_pane_reflect_responsive_plotly(document, comm):
+    curve = hv.Curve([1, 2, 3]).opts(responsive=True, backend='plotly')
+    pane = HoloViews(curve, backend='plotly')
+
+    # Create pane
+    row = pane.get_root(document, comm=comm)
+
+    assert row.sizing_mode == 'stretch_both'
+    assert pane.sizing_mode == 'stretch_both'
+
+    pane.object = hv.Curve([1, 2, 3])
+
+    assert row.sizing_mode is None
+    assert pane.sizing_mode is None
 
 @hv_available
 def test_holoviews_widgets_from_dynamicmap(document, comm):
@@ -510,7 +602,7 @@ def test_holoviews_link_across_panes(document, comm):
 
     RangeToolLink(c1, c2)
 
-    layout = Row(Pane(c1, backend='bokeh'), Pane(c2, backend='bokeh'))
+    layout = Row(pn.panel(c1, backend='bokeh'), pn.panel(c2, backend='bokeh'))
     row = layout.get_root(document, comm=comm)
 
     assert len(row.children) == 2
@@ -534,7 +626,7 @@ def test_holoviews_link_after_adding_item(document, comm):
 
     RangeToolLink(c1, c2)
 
-    layout = Row(Pane(c1, backend='bokeh'))
+    layout = Row(pn.panel(c1, backend='bokeh'))
     row = layout.get_root(document, comm=comm)
 
     assert len(row.children) == 1
@@ -544,7 +636,7 @@ def test_holoviews_link_after_adding_item(document, comm):
     range_tool = row.select_one({'type': RangeTool})
     assert range_tool is None
 
-    layout.append(Pane(c2, backend='bokeh'))
+    layout.append(pn.panel(c2, backend='bokeh'))
     _, p2 = row.children
     assert isinstance(p2, Figure)
     range_tool = row.select_one({'type': RangeTool})
@@ -562,7 +654,7 @@ def test_holoviews_link_within_pane(document, comm):
 
     RangeToolLink(c1, c2)
 
-    pane = Pane(Pane(hv.Layout([c1, c2]), backend='bokeh'))
+    pane = pn.panel(pn.panel(hv.Layout([c1, c2]), backend='bokeh'))
     column = pane.get_root(document, comm=comm)
 
     assert len(column.children) == 1
@@ -586,7 +678,7 @@ def test_holoviews_link_within_pane(document, comm):
 def test_holoviews_property_override(document, comm):
     c1 = hv.Curve([])
 
-    pane = Pane(c1, backend='bokeh', background='red',
+    pane = pn.panel(c1, backend='bokeh', background='red',
                 css_classes=['test_class'])
     model = pane.get_root(document, comm=comm)
 
