@@ -91,7 +91,7 @@ def test_load_from_stringio():
 
 def test_loading_a_image_from_url():
     """Tests the loading of a image from a url"""
-    url = 'https://raw.githubusercontent.com/holoviz/panel/master/doc/_static/logo.png'
+    url = 'https://raw.githubusercontent.com/holoviz/panel/main/doc/_static/logo.png'
 
     image_pane = PNG(url)
     image_data = image_pane._data()
@@ -116,7 +116,7 @@ def test_loading_a_image_from_pathlib():
 
 def test_image_alt_text(document, comm):
     """Tests the loading of a image from a url"""
-    url = 'https://raw.githubusercontent.com/holoviz/panel/master/doc/_static/logo.png'
+    url = 'https://raw.githubusercontent.com/holoviz/panel/main/doc/_static/logo.png'
 
     image_pane = PNG(url, embed=False, alt_text="Some alt text")
     model = image_pane.get_root(document, comm)
@@ -126,7 +126,7 @@ def test_image_alt_text(document, comm):
 
 def test_image_link_url(document, comm):
     """Tests the loading of a image from a url"""
-    url = 'https://raw.githubusercontent.com/holoviz/panel/master/doc/_static/logo.png'
+    url = 'https://raw.githubusercontent.com/holoviz/panel/main/doc/_static/logo.png'
 
     image_pane = PNG(url, embed=False, link_url="http://anaconda.org")
     model = image_pane.get_root(document, comm)
