@@ -1,14 +1,16 @@
-from datetime import datetime, date
+from datetime import date, datetime
+from pathlib import Path
 
 import numpy as np
 import pytest
 
 from bokeh.models.widgets import FileInput as BkFileInput
+
 from panel import config
 from panel.widgets import (
     ArrayInput, Checkbox, DatePicker, DatetimeInput, DatetimePicker,
-    DatetimeRangeInput, DatetimeRangePicker, FileInput, LiteralInput,
-    TextInput, StaticText, IntInput, FloatInput
+    DatetimeRangeInput, DatetimeRangePicker, FileInput, FloatInput, IntInput,
+    LiteralInput, StaticText, TextInput,
 )
 
 
@@ -59,7 +61,7 @@ def test_date_picker(document, comm):
 def test_datetime_picker(document, comm):
     datetime_picker = DatetimePicker(
         name='DatetimePicker', value=datetime(2018, 9, 2, 1, 5),
-        start=date(2018, 9, 1), end=date(2018, 9, 10)
+        start=date(2018, 9, 1), end=datetime(2018, 9, 10)
     )
 
     widget = datetime_picker.get_root(document, comm=comm)
@@ -67,8 +69,8 @@ def test_datetime_picker(document, comm):
     assert isinstance(widget, datetime_picker._widget_type)
     assert widget.title == 'DatetimePicker'
     assert widget.value == '2018-09-02 01:05:00'
-    assert widget.min_date == '2018-09-01'
-    assert widget.max_date == '2018-09-10'
+    assert widget.min_date == '2018-09-01T00:00:00'
+    assert widget.max_date == '2018-09-10T00:00:00'
 
     datetime_picker._process_events({'value': '2018-09-03 03:00:01'})
     assert datetime_picker.value == datetime(2018, 9, 3, 3, 0, 1)
@@ -83,15 +85,20 @@ def test_datetime_picker(document, comm):
     assert datetime_picker._deserialize_value(value) == '2018-09-04 12:01:00'
     assert datetime_picker._serialize_value(datetime_picker._deserialize_value(value)) == value
 
+    # Check start value
+    with pytest.raises(ValueError):
+        datetime_picker._process_events({'value': '2018-08-31 23:59:59'})
+
     # Check end value
-    datetime_picker._process_events({'value': '2018-09-10 03:00:01'})
-    assert datetime_picker.value == datetime(2018, 9, 10, 0, 0, 0)
+    with pytest.raises(ValueError):
+        datetime_picker._process_events({'value': '2018-09-10 00:00:01'})
+
 
 
 def test_datetime_range_picker(document, comm):
     datetime_range_picker = DatetimeRangePicker(
         name='DatetimeRangePicker', value=(datetime(2018, 9, 2, 1, 5), datetime(2018, 9, 2, 1, 6)),
-        start=date(2018, 9, 1), end=date(2018, 9, 10)
+        start=date(2018, 9, 1), end=datetime(2018, 9, 10)
     )
 
     widget = datetime_range_picker.get_root(document, comm=comm)
@@ -99,8 +106,8 @@ def test_datetime_range_picker(document, comm):
     assert isinstance(widget, datetime_range_picker._widget_type)
     assert widget.title == 'DatetimeRangePicker'
     assert widget.value == '2018-09-02 01:05:00 to 2018-09-02 01:06:00'
-    assert widget.min_date == '2018-09-01'
-    assert widget.max_date == '2018-09-10'
+    assert widget.min_date == '2018-09-01T00:00:00'
+    assert widget.max_date == '2018-09-10T00:00:00'
 
     datetime_range_picker._process_events({'value': '2018-09-03 03:00:01 to 2018-09-04 03:00:01'})
     assert datetime_range_picker.value == (datetime(2018, 9, 3, 3, 0, 1), datetime(2018, 9, 4, 3, 0, 1))
@@ -114,9 +121,14 @@ def test_datetime_range_picker(document, comm):
     assert datetime_range_picker._deserialize_value(value) == '2018-09-04 12:01:00 to 2018-09-04 12:01:10'
     assert datetime_range_picker._serialize_value(datetime_range_picker._deserialize_value(value)) == value
 
+    # Check start value
+    with pytest.raises(ValueError):
+        datetime_range_picker._process_events({'value': '2018-08-31 23:59:59'})
+
     # Check end value
-    datetime_range_picker._process_events({'value': '2018-09-09 03:00:01 to 2018-09-10 03:00:01'})
-    assert datetime_range_picker.value == (datetime(2018, 9, 9, 3, 0, 1), datetime(2018, 9, 10, 0, 0, 0))
+    with pytest.raises(ValueError):
+        datetime_range_picker._process_events({'value': '2018-09-10 00:00:01'})
+
 
 
 def test_file_input(document, comm):
@@ -345,3 +357,20 @@ def test_array_input(document, comm):
     array_input.value = np.array([1, 2, 3])
     assert not widget.disabled
     assert not array_input._auto_disabled
+
+
+def test_file_input_save_one_file(document, comm, tmpdir):
+    file_input = FileInput(accept='.txt')
+
+    widget = file_input.get_root(document, comm=comm)
+
+    assert isinstance(widget, BkFileInput)
+
+    file_input._process_events({'mime_type': 'text/plain', 'value': 'U29tZSB0ZXh0Cg==', 'filename': 'testfile'})
+
+    fpath = Path(tmpdir) / 'out.txt'
+    file_input.save(str(fpath))
+
+    assert fpath.exists()
+    content = fpath.read_text()
+    assert content == 'Some text\n'
