@@ -3,8 +3,8 @@ from panel.widgets import DiscretePlayer
 
 
 def test_discrete_player(document, comm):
-    discrete_player = DiscretePlayer(name='DiscretePlayer', value=1,
-                                     options=[0.1, 1, 10, 100])
+    discrete_player = DiscretePlayer(name='DiscretePlayer', value=1.,
+                                     options=[0.1, 1., 10, 100])
 
     widget = discrete_player.get_root(document, comm=comm)
 
