@@ -43,6 +43,7 @@ from .io.notebook import (
 from .io.save import save
 from .io.state import curdoc_locked, state
 from .util import escape, param_reprs
+from .util.warnings import deprecated
 
 if TYPE_CHECKING:
     from bokeh.model import Model
@@ -621,7 +622,7 @@ class Viewable(Renderable, Layoutable, ServableMixin):
         if config.comms in ('vscode', 'ipywidgets'):
             widget = ipywidget(self)
             if hasattr(widget, '_repr_mimebundle_'):
-                return widget._repr_mimebundle_(include=include, exclude=exclude)
+                return widget._repr_mimebundle_(include=include, exclude=exclude), {}
             plaintext = repr(widget)
             if len(plaintext) > 110:
                 plaintext = plaintext[:110] + '…'
@@ -714,6 +715,7 @@ class Viewable(Renderable, Layoutable, ServableMixin):
         """
         Prints a compositional repr of the class.
         """
+        deprecated('1.0', f'{type(self).__name__}.pprint', 'print')
         print(self)
 
     def select(
@@ -751,6 +753,7 @@ class Viewable(Renderable, Layoutable, ServableMixin):
         port: int (optional, default=0)
           Allows specifying a specific port
         """
+        deprecated('1.0', f'{type(self).__name__}.app', 'panel.io.notebook.show_server')
         return show_server(self, notebook_url, port)
 
     def embed(
