@@ -19,9 +19,11 @@ from ..reactive import Reactive
 from ..viewable import Layoutable, Viewable
 
 if TYPE_CHECKING:
+
     from bokeh.document import Document
     from bokeh.model import Model
     from pyviz_comms import Comm
+    from typing_extensions import Self
 
     from ..layout.base import ListPanel
 
@@ -68,7 +70,7 @@ class Widget(Reactive):
         super().__init__(**params)
 
     @classmethod
-    def from_param(cls, parameter: param.Parameter, **params) -> Viewable:
+    def from_param(cls, parameter: param.Parameter, **params) -> Self:
         """
         Construct a widget from a Parameter and link the two
         bi-directionally.
@@ -157,7 +159,7 @@ class CompositeWidget(Widget):
         layout_params = [p for p in Layoutable.param if p != 'name']
         layout = {p: getattr(self, p) for p in layout_params
                   if getattr(self, p) is not None}
-        if layout.get('width', self.width) is None and not 'sizing_mode' in layout:
+        if layout.get('width', self.width) is None and 'sizing_mode' not in layout:
             layout['sizing_mode'] = 'stretch_width'
         self._composite = self._composite_type(**layout)
         self._models = self._composite._models
