@@ -1097,7 +1097,7 @@ class ptqdm(_tqdm):
     def display(self, msg=None, pos=None, bar_style=None):
         super().display(msg, pos)
         style = self._indicator.text_pane.style or {}
-        if not "color" in style:
+        if "color" not in style:
             color = self.colour or 'black'
             self._indicator.text_pane.style = dict(style, color=color)
         if self.total is not None and self.n is not None:
