@@ -1,6 +1,12 @@
 """
 Defines a WYSIWYG TextEditor widget based on quill.js.
 """
+from __future__ import annotations
+
+from typing import (
+    TYPE_CHECKING, ClassVar, Mapping, Optional,
+)
+
 import param
 
 from pyviz_comms import JupyterComm
@@ -8,6 +14,11 @@ from pyviz_comms import JupyterComm
 from ..util import lazy_load
 from .base import Widget
 
+if TYPE_CHECKING:
+    from bokeh.document import Document
+    from bokeh.model import Model
+    from pyviz_comms import Comm
+
 
 class TextEditor(Widget):
     """
@@ -37,9 +48,12 @@ class TextEditor(Widget):
 
     value = param.String(doc="State of the current text in the editor")
 
-    _rename = {"value": "text"}
+    _rename: ClassVar[Mapping[str, str | None]] = {"value": "text"}
 
-    def _get_model(self, doc, root=None, parent=None, comm=None):
+    def _get_model(
+        self, doc: Document, root: Optional[Model] = None,
+        parent: Optional[Model] = None, comm: Optional[Comm] = None
+    ) -> Model:
         if self._widget_type is None:
             self._widget_type = lazy_load(
                 'panel.models.quill', 'QuillInput', isinstance(comm, JupyterComm), root
